# Copyright 2005-2024 Canonical Limited. All rights reserved.

from twisted.web.server import Request

from canonical.landscape.api import RESULT_OFFSET, RESULT_LIMIT
from canonical.landscape.api.helpers import paginated
from canonical.landscape.api.jwt_auth import login_required
from canonical.landscape.api.principal import Principal
from canonical.landscape.api.types import ApiResponse
from canonical.landscape.model.main.store import get_main_store
from canonical.landscape.model.main.tag import Tag


@login_required
@paginated
async def tags_list_handler(
    request: Request,
    principal: Principal,
    offset: int = RESULT_OFFSET,
    limit: int = RESULT_LIMIT,
) -> ApiResponse:
    """Retrieves all computer tags that are available."""
    store = get_main_store()

    tags = store.find(Tag.name).order_by(Tag.name)
    count = tags.count()
    tags = tags.config(offset=offset, limit=limit)

    response = {"count": count, "results": list(tags)}

    return response, 200
