"""Types for use in type-hints associated with the API."""

from typing import Awaitable, Callable, Dict, Tuple

from twisted.web.server import Request


ApiResponse = Tuple[Dict[str, any], int]
"""A Flask-like return value for a RequestHandler. Contains a JSON-serializable body and
the HTTP status code.

e.g.: {"result": "ok"}, 200
"""

RequestHandler = Callable[[Request], Awaitable[ApiResponse]]
"""A callable suitable for handling a `Request`.

Should return an awaitable that returns `ApiResponse` This is easily accomplished using an async
function, e.g.:

async def my_request_handler(request: Request):
    return {"result": "ok"}, 200
"""
