# Copyright 2005-2024 Canonical Limited.  All rights reserved.

__clearlist__ = ["DuplicateRoleError", "UnknownRoleError"]


class DuplicateRoleError(Exception):
    """Raised when are role with the given name already exists."""


class InvalidRoleNameError(Exception):
    """Raised when the given name is not valid for a role."""


class InvalidPermissionsError(Exception):
    """Raised when one or more permission names are not valid."""

    def __init__(self, permissions):
        super(InvalidPermissionsError, self).__init__(
            "Invalid permissions: %s" % ", ".join(permissions)
        )
        self.permissions = permissions


class NoRolesError(Exception):
    """Raised when trying to give a user no roles."""


class PersonNotInAccountError(Exception):
    """Raised when attempting to adjust roles on a person who does not belong to the
    given account.
    """


class ReadOnlyRoleError(Exception):
    """Raised when trying to edit a read-only role."""

    def __init__(self, name):
        message = "The role '%s' is read-only" % name
        super(ReadOnlyRoleError, self).__init__(message)


class SelfRevokeGlobalAdminError(Exception):
    """Raised when a person attempts to revoke the 'GlobalAdmin' role from themselves."""


class UnknownRoleError(Exception):
    """Raised when a role with the given name can't be found."""
