# Copyright 2005-2014 Canonical Limited. All rights reserved

from typing import Optional
from canonical.landscape.model.management import ModelManagement
from canonical.landscape.model.alert.rule import (
    Rule,
    get_rule_info_class_by_name,
    InvalidAlertTypeError,
    UnknownAlertError,
    LEGACY_ALERTS,
)


class AlertManagement(ModelManagement):
    def get_computer_alert_by_name(self, name):
        """Return a computer alert with the given C{name}."""
        from canonical.landscape.model.alert.computer import ComputerRuleInfo

        info_class = get_rule_info_class_by_name(name)
        if not issubclass(info_class, ComputerRuleInfo):
            raise InvalidAlertTypeError(
                "An account alert was provided but a " "computer alert is expected."
            )
        return self.account.get_rules(info_classes=[info_class]).one()

    def get_alerts_summary(self, active=None):
        """Return a count of active alerts for all alert types"""

        rules = self.account.get_rules(active=active)

        alerts = []
        for rule in rules:
            alert = rule.info
            alert_type = alert.get_name()

            if alert_type in LEGACY_ALERTS:
                continue

            alerts.append(
                {
                    "id": rule.id,
                    "alert_type": alert_type,
                    "summary": alert.get_summary(),
                    "activation_time": str(alert.get_activation_time()),
                }
            )

        return alerts

    def dismiss_active_alerts(self, id) -> Rule:
        """Dismiss a specific alert with the given C{id}."""
        rule: Optional[Rule] = self.account.get_rule_by_id(id, self.person)

        if rule is not None:
            rule.dismiss_active_alerts()
            return rule
        else:
            raise UnknownAlertError(
                f"The specified alert with key={id} could not be found. Please pass a valid alert id."
            )
