# Copyright 2005-2024 Canonical Limited. All rights reserved.

from zope.interface import implementer

from canonical.routes import route, Redirect
from canonical.security.protect import requires, requires_advisor, PUBLIC, PRIVATE

from canonical.landscape.ui.routes import LandscapeRoutes
from canonical.landscape.model.knowledge.interfaces import IKnowledgeBase

from safe.canonical.landscape.model.knowledge.article import get_article_by_id
from safe.canonical.landscape.model.knowledge.category import get_category_by_id


__all__ = ["AccountKnowledgeBase"]

__clearlist__ = ["AccountKnowledgeBase"]


@requires_advisor
@implementer(IKnowledgeBase)
class AccountKnowledgeBase:

    requires(PUBLIC, PRIVATE, ["account"])
    requires(PUBLIC, PRIVATE, ["url"])

    def __init__(self, account):
        self.account = account
        self.url = f"{account.url}/kb"


class LandscapeKnowledgeRoutes(LandscapeRoutes):
    @route("<id>", permission="landscape.ViewKnowledgeBase", id_pattern="\d+")
    def article_shortcut(self, id):
        article = get_article_by_id(int(id))
        if article:
            raise Redirect(article.url)
        return None

    @route("article/<id>", permission="landscape.ViewKnowledgeBase", id_pattern="\d+")
    def article(self, id):
        return get_article_by_id(int(id))

    @route("category/<id>", permission="landscape.ViewKnowledgeBase", id_pattern="\d+")
    def category(self, id):
        return get_category_by_id(int(id))


class LandscapeArticleRoutes(LandscapeRoutes):
    @route("attachment/<filename>")
    def attachment(self, filename):
        return self.context.get_attachment_by_filename(filename)
